..
    Copyright (C) 2022 CERN.

    invenio-administration is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Changes
=======

Version 1.0.2 (released 2022-11-25)

- use centralized axios configuration
- add i18n translations
- refactor actions buttons

Version 1.0.1 (released 2022-11-04)

- upgrade invenio-records-resources
- upgrade invenio-vocabublaries

Version 1.0.0

- Initial public release.
